@@ -15,7 +15,7 @@ Still, this exact SSA is quite slow, because it insists on simulating every indi
 
 Written by TR Maarleveld, Amsterdam, The Netherlands
 E-mail: tmd200@users.sourceforge.net
-Last Change: 23 October, 2011
+Last Change: 16 November, 2011
 """
 
 __doc__ = """
@@ -165,19 +165,23 @@ class DirectMethod(PySCeS_Connector):
       #####################
       while self.sim_t < self.Endtime and timestep < self.Timesteps:
           self.sim_a_0 = self.sim_a_mu.sum()
-          if self.sim_a_0 <= 0: break                                    # All reactants got exhausted
-          self.Run()                                                     # Run direct SSA
+          if self.sim_a_0 <= 0:                                          # All reactants got exhausted
+             if self.Endtime < self.Timesteps:
+                 last_output = self.sim_output[-1]
+                 last_output[0] = self.Endtime
+                 self.sim_output.append(last_output)                 
+             break            
              
+          self.Run()                                                     # Run direct SSA             
           if self.sim_t > self.event_time and self.event_time != None:   # Time Event
               self.DoEvent()
               self.sim_t = copy.copy(self.event_time)
               self.event_time = None
           
           if self.event_amount != None:                                  # Amount Event
-              if self.X_matrix[self.event_amount_index] > self.event_amount: self.DoEvent()          
-          
-                                                                     # Add 'dt' to a species amou
-          for i in range(len(self.X_matrix)):
+              if self.X_matrix[self.event_amount_index] > self.event_amount: self.DoEvent()        
+                                                                     
+          for i in range(len(self.X_matrix)):                            # Add 'dt' to a species amount:
               try:
                   self.distributions[i][self.sim_output[timestep][i+1]] += self.sim_t - self.sim_output[timestep][0]
               except:     
@@ -195,15 +199,14 @@ class DirectMethod(PySCeS_Connector):
           ###  End output Generation  ###
 	
           timestep += 1
-          self.to_update = self.reagents[self.reaction_index]            # Determine vars to update           
+          self.to_update = self.reagents[self.reaction_index]            # Determine vars to update
           self.Propensities()                                            # Update Propensities
           if self.IsTrackPropensities:
               a_ravel = list(self.sim_a_mu.ravel())
               a_ravel.insert(0,self.sim_t)
               self.propensities_output.append(a_ravel)
-                
-      self.X_matrix = self.X_matrixinit.copy()                           # Reset X for next trajectory calc.
-      #######################################   TODO      
+
+      #######################################   TODO
       self.FillDataStochsim()
       self.data_stochsim.setSimulationInfo(timestep,self.sim_t,traj)
       ######################################
@@ -213,6 +216,7 @@ class DirectMethod(PySCeS_Connector):
           name = self.TempDir+'/'+self.ModelFile+str(traj)+'.dat'
           cPickle.dump(self.data_stochsim,file = open(name,'w'))         # Dump trajectory output
           self.sim_dump.append(name)
+      self.X_matrix = self.X_matrixinit.copy()                           # Reset X for next trajectory calc.          
       traj+=1
 
     t2 = time.time()
@@ -310,10 +314,10 @@ class DirectMethod(PySCeS_Connector):
        - *rate_eval_code*: compiled rate equations
        - *r_vec*: output for the calculated propensities
       """
-      try: exec(rate_eval_code)     
-      except:
-          print "Error: It is impossible to determine the propensities. Check if all variable concentrations are initialized"
-          sys.exit()
+      exec(rate_eval_code)     
+      #except:
+      #    print "Error: It is impossible to determine the propensities. Check if all variable concentrations are initialized"
+      #    sys.exit()
 
   def Propensities(self):
       """ Determines the propensities to fire for each reaction at the current time point. At t=0, all the rate equations are compiled. """   
