@@ -8,7 +8,7 @@ Channels", J. Phys. Chem., 2000,104,1876-1889
 
 Written by TR Maarleveld, Amsterdam, The Netherlands
 E-mail: tmd200@users.sourceforge.net
-Last Change: November 3, 2011
+Last Change: November 16, 2011
 """
 from stochpy import model_dir
 import sys,copy,time,heapq,cPickle,os,re
@@ -150,8 +150,13 @@ Channels", J. Phys. Chem., 2000,104,1876-1889
               i+=1
       #####################
       while self.sim_t < self.Endtime and timestep < self.Timesteps:  
-        self.a_0 = self.sim_a_mu.sum()
-        if self.a_0 <= 0: break                             # All reactants got exhausted
+        self.sim_a_0 = self.sim_a_mu.sum()
+        if self.sim_a_0 <= 0:                                          # All reactants got exhausted
+           if self.Endtime < self.Timesteps:
+               last_output = self.sim_output[-1]
+               last_output[0] = self.Endtime
+               self.sim_output.append(last_output)                 
+           break       
         if self.IsTrackPropensities:
             a_ravel = list(self.sim_a_mu.ravel())
             a_ravel.insert(0,self.sim_t)
