@@ -303,23 +303,22 @@ class SSA():
     try: self.DeleteTempfiles()						# Delete '.dat' files
     except: pass
     t1 = time.time()
-
     if self.sim_method_name == "TauLeaping":
-      if self.sim_mode == 'time':
-          self.SSA.Execute(self.sim_trajectories,self.sim_end,10**10,self.IsTrackPropensities,epsilon)
-      elif self.sim_mode == 'steps':
-          self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities,epsilon)
-      else:
-          print "Error: Simulation mode should be 'time' or 'steps'. Steps is done by default"
-          self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
+        if self.sim_mode == 'time':
+            self.SSA.Execute(self.sim_trajectories,self.sim_end,10**10,self.IsTrackPropensities,epsilon)
+        elif self.sim_mode == 'steps':
+            self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities,epsilon)
+        else:
+            print "Error: Simulation mode should be 'time' or 'steps'. Steps is done by default"
+            self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
     else:
-      if self.sim_mode == 'time':
-          self.SSA.Execute(self.sim_trajectories,self.sim_end,10**10,self.IsTrackPropensities)
-      elif self.sim_mode == 'steps':
-          self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
-      else:
-          print "Error: Simulation mode should be 'time' or 'steps'. Steps is done by default"
-          self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
+        if self.sim_mode == 'time':
+            self.SSA.Execute(self.sim_trajectories,self.sim_end,10**10,self.IsTrackPropensities)
+        elif self.sim_mode == 'steps':          
+            self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
+        else:
+            print "Error: Simulation mode should be 'time' or 'steps'. Steps is done by default"
+            self.SSA.Execute(self.sim_trajectories,10**10,self.sim_end,self.IsTrackPropensities)
 
     t2 = time.time()  
     self.IsSimulationDone = True
@@ -328,16 +327,16 @@ class SSA():
     try: self.plot = Analysis.DoPlotting(self.data_stochsim.species_labels,self.SSA.rate_names,self.plot.plotnum)
     except: self.plot = Analysis.DoPlotting(self.data_stochsim.species_labels,self.SSA.rate_names)
   
-  def PlotTimeSim(self,species2plot = True,linestyle = 'None',marker = 'o',colors = None,title = 'StochPy Time Simulation Plot'):
+  def PlotTimeSim(self,species2plot = True,linestyle = 'solid',marker = '',colors = None,title = 'StochPy Time Simulation Plot'):
     """
     Plot time simulation output for each generated trajectory
     Default: PlotTimeSim() plots time simulation for each species
 
     Input:
      - *species2plot*: [default = True] as a list ['S1','S2'] 
-     - *linestyle*: [default = 'None'] dashed, solid, and dash_dot (string)
-     - *marker* [default = 'o'] ('v','o','*',',')
-     - *title*: [default = '']  (string)
+     - *linestyle*: [default = 'solid'] dashed, solid, and dash_dot (string)
+     - *marker* [default = ''] ('v','o','*',',')
+     - *title*: [default = 'StochPy Time Simulation Plot']  (string)
     """
     if not self.IsSimulationDone: self.DoStochSim()
     if species2plot == True: species2plot = self.data_stochsim.species_labels
@@ -359,7 +358,9 @@ class SSA():
                   if self.SSA.Trajectories > 1: self.plot.plotnum-=1
                   traj+=1
               if traj > 1: self.plot.plotnum+=1
-          except: print "Error: MatPlotlib is not available"
+          except: 
+              print "Error: MatPlotlib is not available"
+              print "Info: Use the print function: PrintTimeSim()"
  
   def PrintTimeSim(self):
     """ Print time simulation output for each generated trajectory"""
@@ -414,7 +415,7 @@ class SSA():
             if traj > 1: self.plot.plotnum += 1
         except:
             print "Error: The Matplotlib module is not available, so it is impossible to create plots"
-            print "Info: See http://matplotlib.sourceforge.net/"
+            print "Info: Use the print function: PrintDistributions()"
 
   def PrintDistributions(self):
     """ Print obtained distributions for each generated trajectory """
@@ -431,7 +432,7 @@ class SSA():
                 print species[0][i],"\t",species[1][i]
         traj+=1
 
-  def PlotPropensities(self,rates2plot = True,linestyle = 'None',marker = 'o',colors = None,title = 'StochPy Propensities Plot'):
+  def PlotPropensities(self,rates2plot = True,linestyle = 'solid',marker = '',colors = None,title = 'StochPy Propensities Plot'):
     """ 
     Plot time simulation output for each generated trajectory
 
@@ -439,8 +440,8 @@ class SSA():
 
     Input:
      - *rates2plot* [default = True]: species as a list ['S1','S2']
-     - *marker* [default = 'o'] ('v','o','*',',')
-     - *linestyle* [default = 'None']: dashed, dotted, and solid (string)
+     - *marker* [default = ''] ('v','o','*',',')
+     - *linestyle* [default = 'solid']: dashed, dotted, and solid (string)
      - *colors* [default = None] (list)
      - *title* [default = 'StochPy Propensities Plot'] (string)
     """
@@ -458,20 +459,19 @@ class SSA():
             IsPlot = False
 
     if IsPlot:
-         try:
+        try:
             traj = 1
             while traj <= self.SSA.Trajectories:	
                 if self.SSA.Trajectories > 1:        
                     File = open(self.temp_dir+'/'+self.model_file+str(traj)+'.dat','r')	# Open dumped output
                     self.data_stochsim = cPickle.load(File)
 
-                self.plot.Propensities(self.data_stochsim,rates2plot,traj-1,linestyle,marker,colors,title) # Plot props time sim 
+                self.plot.Propensities(self.data_stochsim.getPropensities(),rates2plot,traj-1,linestyle,marker,colors,title) # Plot props time sim 
                 if self.SSA.Trajectories > 1: self.plot.plotnum-=1
                 traj+=1
             if traj > 1: self.plot.plotnum+=1
-         except:
+        except:
             print "Error: The Matplotlib module is not available, so it is impossible to create plots"
-            print "Info: See http://matplotlib.sourceforge.net/"
             print "Info: Use the print function: PrintPropensities()"
 
   def PrintPropensities(self):
@@ -607,39 +607,38 @@ class SSA():
   def GetInterpolatedData(self):
     """ Perform linear interpolation for each generated trajectory. Linear interpolation is done for all integer time points, between the start time (0) end the endtime. """
     if not self.IsSimulationDone: self.DoStochSim()
-    self.data_stochsim_interpolated = InterpolatedDataObj()
-
+    self.data_stochsim_interpolated = InterpolatedDataObj()    
     for species in self.data_stochsim.species_labels: self.data_stochsim_interpolated.species.append([])
     if self.sim_mode == 'time': self.data_stochsim_interpolated.points = range(int(self.sim_end)+1) # Points for interpolation    
     traj = 1
     while traj <= self.SSA.Trajectories:
       if self.SSA.Trajectories > 1:
           File = open(self.temp_dir+'/'+self.model_file+str(traj)+'.dat','r')
-          self.data_stochsim = cPickle.load(File)      
+          self.data_stochsim = cPickle.load(File)
 
-      if not self.sim_mode == 'time':                
+      if not self.sim_mode == 'time':          
           endtime = int(ceil(self.data_stochsim.time[-1][0]))
           if traj == 1: self.data_stochsim_interpolated.points = range(endtime+1)
           if endtime < self.data_stochsim_interpolated.points[-1]: self.data_stochsim_interpolated.points = range(endtime+1) 	 # Points for interpolation
          
       i=0
+      xp = self.data_stochsim.time.flatten()
       for species in self.data_stochsim.species_labels:
-          xp = self.data_stochsim.time.flatten()
-          fp = self.data_stochsim.species[:,i]       
+          fp = self.data_stochsim.species[:,i]
           temp_interpolated_output = []
           n=0
           for value in self.data_stochsim_interpolated.points:
               while n<len(xp):
-                if value > xp[n]: n+=1              
-                else:
-                    if value: temp_interpolated_output.append(fp[n-1])
-                    else: temp_interpolated_output.append(fp[0])
-                    break
-
-          self.data_stochsim_interpolated.species[i].append(temp_interpolated_output)  
-          i+=1    
+                  if value > xp[n]: n+=1
+                  else:
+                      if value: temp_interpolated_output.append(fp[n-1])
+                      else: temp_interpolated_output.append(fp[0])
+                      break
+          if xp[-1] < self.data_stochsim_interpolated.points[-1]: temp_interpolated_output.append(temp_interpolated_output[-1])
+          self.data_stochsim_interpolated.species[i].append(temp_interpolated_output)
+          i+=1
       traj+=1
-    self.data_stochsim_interpolated.means,self.data_stochsim_interpolated.standard_deviations,self.data_stochsim_interpolated.time = Analysis.ObtainInterpolationResults(self.data_stochsim_interpolated.species,self.data_stochsim_interpolated.points)   
+    self.data_stochsim_interpolated.means,self.data_stochsim_interpolated.standard_deviations,self.data_stochsim_interpolated.time = Analysis.ObtainInterpolationResults(self.data_stochsim_interpolated.species,self.data_stochsim_interpolated.points,self.data_stochsim_interpolated.points[-1])
     self.HasInterpol = True
 
   def PrintInterpolatedData(self):    
@@ -680,7 +679,7 @@ class SSA():
       if title == 'StochPy Interpolated Time Plot (# of trajectories = )':
           title = title.replace('= ','= '+str(self.SSA.Trajectories)) 
       if not self.IsSimulationDone: self.DoStochSim()
-      if not self.HasInterpol: self.GetInterpolatedData()     
+      if not self.HasInterpol: self.GetInterpolatedData() 
       try:
           self.plot.AverageTimeSimulation(self.data_stochsim_interpolated.means,self.data_stochsim_interpolated.standard_deviations,self.data_stochsim_interpolated.time,species2plot,linestyle,marker,colors,title)
       except:
@@ -718,6 +717,10 @@ class SSA():
      - *directory*: [default = None] (string)
     """
     if directory == None: directory = self.output_dir + '/' + self.model_file+'_' + what
+    else:
+       if not os.path.exists(directory):
+          os.makedirs(directory)
+       directory += '/' + self.model_file+'_' + what
     if what == 'TimeSim':
         if not self.IsSimulationDone: self.DoStochSim()
         traj = 1
@@ -800,14 +803,12 @@ class SSA():
     elif what == 'Interpol':
         if not self.IsSimulationDone: self.DoStochSim()
         if not self.HasInterpol: self.GetInterpolatedData()
-        self.data_stochsim_interpolated.means,self.data_stochsim_interpolated.standard_deviations,self.data_stochsim_interpolated.time =  Analysis.ObtainInterpolationResults(self.data_stochsim_interpolated.species,self.data_stochsim_interpolated.points)
 
         Dir = directory + '.txt'
         f = open(Dir,'w')
         f.write("t")
         for species in self.data_stochsim.species_labels: f.write("\tMean "+str(species[4:])+"\tSD "+str(species[4:]))
         f.write("\n")
-
         means = np.transpose(self.data_stochsim_interpolated.means)
         sds = np.transpose(self.data_stochsim_interpolated.standard_deviations)
         for t in range(self.data_stochsim_interpolated.time[-1]+1):
@@ -838,7 +839,7 @@ class SSA():
       """ Deletes all .dat files """
       for line in self.SSA.Dump: os.remove(line)
 
-  def DoTestsuite(self,epsilon_ = 0.01):
+  def DoTestsuite(self,epsilon_ = 0.01,sim_trajectories=1000):
       """
       Do 10000 simulations until t=50 and print the interpolated result for t = 0,1,2,...,50
       
@@ -847,12 +848,12 @@ class SSA():
       """
       self.sim_end = 50
       self.sim_mode = "time"
-      self.sim_trajectories = 10000
-      self.DoStochSim(epsilon = epsilon_ )    
+      self.sim_trajectories = sim_trajectories
+      self.DoStochSim(epsilon = epsilon_) 
       self.PrintInterpolatedData()    
-      self.sim_end = 1000                           # Reset settings to default values
-      self.sim_mode = "steps"
-      self.sim_trajectories = 1
+      #self.sim_end = 1000                           # Reset settings to default values
+      #self.sim_mode = "steps"
+      #self.sim_trajectories = 1
  
 if __name__ == "__main__": 
   modelfile = "ImmigrationDeath.psc" 				# Default model
