@@ -9,7 +9,7 @@ This program performs Optimized Explicit Tau-leaping algorithm, which is an appr
 
 Written by TR Maarleveld, Amsterdam, The Netherlands
 E-mail: tmd200@users.sourceforge.net
-Last Change: November 3, 2011
+Last Change: November 16, 2011
 """
 ############################## IMPORTS ###################################
 
@@ -167,18 +167,23 @@ class OTL(PySCeS_Connector):
             self.Propensities()
             self.GetG(orders,hors,HO_info)
             self.sim_a_0 = self.sim_a_mu.sum()           
-            if self.sim_a_0 <= 0:  break 	
+            if self.sim_a_0 <= 0:                                          # All reactants got exhausted
+                if self.Endtime < self.Timesteps:
+                    last_output = self.sim_output[-1]
+                    last_output[0] = self.Endtime
+                    self.sim_output.append(last_output)
+                break	
             self.GetMuVar()
-            self.GetTauPrime()  
+            self.GetTauPrime()
 
         ##################### start Possible Feedback loop ##################
-        self.DetermineMethod()    
-        ##### Optimized Tau-Leaping step ##### 
+        self.DetermineMethod()
+        ##### Optimized Tau-Leaping step #####
 
-        if self.IsOTL:          
+        if self.IsOTL:
           self.GetTauPrimePrime()
-          self.GetK()         
-          self.Execute_K_Reactions() 
+          self.GetK()
+          self.Execute_K_Reactions()
           if not self.IsNegative:
             if self.IsTrackPropensities:
                 a_ravel = list(self.sim_a_mu.ravel())
@@ -190,15 +195,15 @@ class OTL(PySCeS_Connector):
             if self.sim_t > self.event_time and self.event_time != None:
                 self.DoEvent()
                 self.sim_t = copy.copy(self.event_time)
-                self.event_time = None          
+                self.event_time = None
             if self.event_amount != None:
-                if self.X_matrix[self.event_amount_index] > self.event_amount: self.DoEvent()                
+                if self.X_matrix[self.event_amount_index] > self.event_amount: self.DoEvent()
             
             for i in range(len(self.X_matrix)):
                 try:
                     self.distributions[i][self.sim_output[timestep][i+1]] += self.sim_t - self.sim_output[timestep][0]
-                except:     
-                    self.distributions[i][self.sim_output[timestep][i+1]] = self.sim_t - self.sim_output[timestep][0]                  
+                except:
+                    self.distributions[i][self.sim_output[timestep][i+1]] = self.sim_t - self.sim_output[timestep][0]
 
             ### Start output Generation ### TODO
             temp = list(self.X_matrix)
@@ -223,7 +228,12 @@ class OTL(PySCeS_Connector):
                 self.propensities_output.append(a_ravel)
 
             self.sim_a_0 = self.sim_a_mu.sum()  
-            if self.sim_a_0 == 0: break
+            if self.sim_a_0 <= 0:                                          # All reactants got exhausted
+               if self.Endtime < self.Timesteps:
+                   last_output = self.sim_output[-1]
+                   last_output[0] = self.Endtime
+                   self.sim_output.append(last_output)                 
+               break       
             self.RunExactSSA()
                 
             if self.sim_t > self.event_time and self.event_time != None:
